aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/contrib/lite/models
diff options
context:
space:
mode:
authorGravatar A. Unique TensorFlower <gardener@tensorflow.org>2017-11-30 09:52:28 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2017-11-30 09:56:18 -0800
commit9308470197bcc068dca9fe227d0ab144157950e1 (patch)
tree7c4eead75bfa04311e192d3aa6afc08b2d85930a /tensorflow/contrib/lite/models
parent1c4810141e71289d71bfd94a74434bd09ee6b20f (diff)
Rename tests.
PiperOrigin-RevId: 177467740
Diffstat (limited to 'tensorflow/contrib/lite/models')
-rw-r--r--tensorflow/contrib/lite/models/speech_asr_am_model_test.cc (renamed from tensorflow/contrib/lite/models/speech_terse_am_model_test.cc)10
-rw-r--r--tensorflow/contrib/lite/models/speech_asr_lm_model_test.cc (renamed from tensorflow/contrib/lite/models/speech_terse_lm_model_test.cc)8
2 files changed, 9 insertions, 9 deletions
diff --git a/tensorflow/contrib/lite/models/speech_terse_lm_model_test.cc b/tensorflow/contrib/lite/models/speech_asr_lm_model_test.cc
index 04c54ffb22..53f2b66da4 100644
--- a/tensorflow/contrib/lite/models/speech_terse_lm_model_test.cc
+++ b/tensorflow/contrib/lite/models/speech_asr_lm_model_test.cc
@@ -59,10 +59,10 @@ static void ClearLstmStates(Interpreter* interpreter) {
interpreter->tensor(kLstmLayer3CellStateTensor)->bytes);
}
-TEST(SpeechTerseLm, EndToEndTest) {
+TEST(SpeechAsrLm, EndToEndTest) {
// Read the model.
string tflite_file_path =
- file::JoinPath(TestDataPath(), "speech_terse_lm_model.tflite");
+ file::JoinPath(TestDataPath(), "speech_asr_lm_model.tflite");
auto model = FlatBufferModel::BuildFromFile(tflite_file_path.c_str());
CHECK(model) << "Failed to mmap model " << tflite_file_path;
@@ -76,13 +76,13 @@ TEST(SpeechTerseLm, EndToEndTest) {
// Load the input frames.
Frames input_frames;
const string input_file_path =
- file::JoinPath(TestDataPath(), "speech_terse_lm_model_in.csv");
+ file::JoinPath(TestDataPath(), "speech_asr_lm_model_in.csv");
ReadFrames(input_file_path, &input_frames);
// Load the golden output results.
Frames output_frames;
const string output_file_path =
- file::JoinPath(TestDataPath(), "speech_terse_lm_model_out.csv");
+ file::JoinPath(TestDataPath(), "speech_asr_lm_model_out.csv");
ReadFrames(output_file_path, &output_frames);
CHECK_EQ(interpreter->tensor(kModelInput1Tensor)->dims->size, 1);
diff --git a/tensorflow/contrib/lite/models/speech_terse_am_model_test.cc b/tensorflow/contrib/lite/models/speech_asr_am_model_test.cc
index 30d89a1354..bf95b313f3 100644
--- a/tensorflow/contrib/lite/models/speech_terse_am_model_test.cc
+++ b/tensorflow/contrib/lite/models/speech_asr_am_model_test.cc
@@ -12,7 +12,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
==============================================================================*/
// Unit test for speech TERSE AM model using TFLite Ops.
#include <string.h>
@@ -45,10 +45,10 @@ constexpr int kLstmLayer5OutputStateTensor = 103;
constexpr int kLstmLayer5CellStateTensor = 104;
constexpr int kModelOutputTensor = 109;
-TEST(SpeechTerseAm, RandomIOTest) {
+TEST(SpeechAsrAm, RandomIOTest) {
// Read the model.
string tflite_file_path =
- file::JoinPath(TestDataPath(), "speech_terse_am_model.tflite");
+ file::JoinPath(TestDataPath(), "speech_asr_am_model.tflite");
auto model = FlatBufferModel::BuildFromFile(tflite_file_path.c_str());
CHECK(model) << "Failed to mmap model " << tflite_file_path;
@@ -62,13 +62,13 @@ TEST(SpeechTerseAm, RandomIOTest) {
// Load the input frames.
Frames input_frames;
const string input_file_path =
- file::JoinPath(TestDataPath(), "speech_terse_am_model_in.csv");
+ file::JoinPath(TestDataPath(), "speech_asr_am_model_in.csv");
ReadFrames(input_file_path, &input_frames);
// Load the golden output results.
Frames output_frames;
const string output_file_path =
- file::JoinPath(TestDataPath(), "speech_terse_am_model_out.csv");
+ file::JoinPath(TestDataPath(), "speech_asr_am_model_out.csv");
ReadFrames(output_file_path, &output_frames);
const int speech_batch_size =
@@ -12,7 +12,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
limitations under the License.
==============================================================================*/
-// Unit test for speech TERSE AM model using TFLite Ops.
+// Unit test for speech ASR AM model using TFLite Ops.
#include <string.h>